@@ -1,9 +1,9 @@
 PS1='$ '
 TOMCAT_DST_FOLDER="tomcat"
-TOMCAT_VERSION="7.0.82"
+TOMCAT_VERSION="8.5.47"
 TOMCAT_PID_FILENAME="tomcat.pid"
 SMARTGEAR_DISTRIBUTION_DIRECTORY=$(ls -d smartgears-distribution-*)
-SMARTGEAR_ROOT=/var/lib/jenkins
+SMARTGEAR_ROOT=${PWD}
 
 BUNDLE_HOME=${SMARTGEAR_ROOT}
 STARTUP_SCRIPT="startContainer.sh"
